summaryrefslogtreecommitdiff
path: root/src/mongo/db/exec/fetch.h
diff options
context:
space:
mode:
authorMathias Stearn <mathias@10gen.com>2014-11-26 15:04:26 -0500
committerMathias Stearn <mathias@10gen.com>2014-11-26 15:15:59 -0500
commit16a8ef7ad60d498b69bdc0ad5cbca44757d16fd8 (patch)
tree2d9f056acf8f1b9b2e943f82e315bdf019475a38 /src/mongo/db/exec/fetch.h
parentcb5cab88761d9aca75e064665cce89f579c69e36 (diff)
downloadmongo-16a8ef7ad60d498b69bdc0ad5cbca44757d16fd8.tar.gz
SERVER-13679 Replace DiskLoc with RecordId outside of MMAPv1
Operations: sed -i -e 's/\<DiskLoc\>/RecordId/g' sed -i -e 's/\<DiskLocs\>/RecordIds/g' sed -i -e 's/\<minDiskLoc\>/RecordId::min()/g' sed -i -e 's/\<maxDiskLoc\>/RecordId::max()/g' sed -i -e 's/\<getDiskLoc\>/getRecordId/g'' Changes under mmap_v1 were reverted and redone by hand as needed.
Diffstat (limited to 'src/mongo/db/exec/fetch.h')
-rw-r--r--src/mongo/db/exec/fetch.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/mongo/db/exec/fetch.h b/src/mongo/db/exec/fetch.h
index 8ea33b0a1ae..3c8b5c00b6a 100644
--- a/src/mongo/db/exec/fetch.h
+++ b/src/mongo/db/exec/fetch.h
@@ -36,12 +36,12 @@
namespace mongo {
/**
* This stage turns a DiskLoc into a BSONObj.
*
* In WorkingSetMember terms, it transitions from LOC_AND_IDX to LOC_AND_UNOWNED_OBJ by reading
* the record at the provided loc. Returns verbatim any data that already has an object.
*
- * Preconditions: Valid DiskLoc.
+ * Preconditions: Valid RecordId.
*/
class FetchStage : public PlanStage {
public:
@@ -58,7 +58,7 @@ namespace mongo {
virtual void saveState();
virtual void restoreState(OperationContext* opCtx);
- virtual void invalidate(OperationContext* txn, const DiskLoc& dl, InvalidationType type);
+ virtual void invalidate(OperationContext* txn, const RecordId& dl, InvalidationType type);
virtual std::vector<PlanStage*> getChildren() const;
@@ -94,7 +94,7 @@ namespace mongo {
// The filter is not owned by us.
const MatchExpression* _filter;
// If we want to return a DiskLoc and it points to something that's not in memory,
// we return a "please page this in" result. We add a RecordFetcher given back to us by the
// storage engine to the WSM. The RecordFetcher is used by the PlanExecutor when it handles
// the fetch request.
@@ -36,12 +36,12 @@
namespace mongo {
/**
- * This stage turns a DiskLoc into a BSONObj.
+ * This stage turns a RecordId into a BSONObj.
*
* In WorkingSetMember terms, it transitions from LOC_AND_IDX to LOC_AND_UNOWNED_OBJ by reading
@@ -94,7 +94,7 @@ namespace mongo {
// The filter is not owned by us.
const MatchExpression* _filter;
- // If we want to return a DiskLoc and it points to something that's not in memory,
+ // If we want to return a RecordId and it points to something that's not in memory,
// we return a "please page this in" result. We add a RecordFetcher given back to us by the
// storage engine to the WSM. The RecordFetcher is used by the PlanExecutor when it handles